@@ -48,7 +48,7 @@ const OffsetController = new Lang.Class({
     getOffset: function() {
         return this._offset;
     },
-    
+
     getEndIdx: function() {
         totItems = MainWindow.list.getItemCount();
         if (CurrentEndIdx < totItems) {
@@ -56,14 +56,14 @@ const OffsetController = new Lang.Class({
         } else {
             this.endIdx = totItems - 1;
         }
-        
+
         return this.endIdx;
     },
-    
+
     increaseEndIdxStep: function() {
         CurrentEndIdx += _OFFSET_STEP;
     },
-    
+
     getcidx: function() {
         return CurrentEndIdx;
     }
@@ -71,12 +71,11 @@ const OffsetController = new Lang.Class({
 
 const DisplayTime = new Lang.Class({
     Name: 'DisplayTime',
-    
-    getDisplayTime: function(timeVal) {
+
+    getDisplayTime: function(mtime) {
         let text = "";
         let DAY = 86400000000;
         let now = GLib.DateTime.new_now_local();
-        let mtime = GLib.DateTime.new_from_timeval_local(timeVal);
         let difference = now.difference(mtime);
         let days = Math.floor(difference / DAY);
         let weeks = Math.floor(difference / (7 * DAY));
@@ -112,6 +111,6 @@ const DisplayTime = new Lang.Class({
         }
         return text;
     }
-});    
+});
 
 
